import numpy as np
import cv2 as cv

cap = cv.VideoCapture(0)

# Teinte
h_red = 0
h_green = 75 #100°
h_var = 5 #+|-10°

# Saturation
low_sat = 70 #~24%
high_sat = 255 #100%

# Valeur
low_bright = 50 #~20%
high_bright = 255 #100%

# Red color
low_red_1 = np.array([0, low_sat, low_bright])
high_red_1 = np.array([h_var, high_sat, high_bright])
low_red_2 = np.array([180-h_var, low_sat, low_bright])
high_red_2 = np.array([180, high_sat, high_bright])

# Green color
low_green = np.array([h_green-h_var, low_sat, low_bright])
high_green = np.array([h_green+h_var, high_sat, high_bright])

# Kernel
kernel = np.ones((15,15),np.uint8)

def cup_detection():
    pass

if not cap.isOpened():
    print("Cannot open camera")
    exit()

while True:
    # Capture frame-by-frame
    ret, frame = cap.read()
    hsv_frame = cv.cvtColor(frame, cv.COLOR_BGR2HSV)
    # red hsv
    red_mask_1 = cv.inRange(hsv_frame, low_red_1, high_red_1)
    red_mask_2 = cv.inRange(hsv_frame, low_red_2, high_red_2)
    red_mask = cv.bitwise_or(red_mask_1,red_mask_2)
    red_trf = cv.morphologyEx(red_mask, cv.MORPH_OPEN, kernel)
    red_hsv = cv.bitwise_and(frame, frame, mask=red_trf)
    # green hsv
    green_mask = cv.inRange(hsv_frame, low_green, high_green)
    green_trf = cv.morphologyEx(green_mask, cv.MORPH_DILATE, kernel)
    green_trf = cv.morphologyEx(green_trf, cv.MORPH_CLOSE, kernel)
    green_hsv = cv.bitwise_and(frame, frame, mask=green_trf)
   
    contours,_ = cv.findContours(red_trf, cv.RETR_EXTERNAL, cv.CHAIN_APPROX_NONE)

    for contour in contours:
        (x,y,w,h) = cv.boundingRect(contour)
        cv.rectangle(red_hsv, (x,y), (x+w,y+h), (0,255,0), 2)

    if not ret:
        print("Can't receive frame (stream end?). Exiting ...")
        break
    # Display the resulting frame
    cv.imshow('green_hsv', green_hsv)
    cv.imshow('red_hsv', red_hsv)
    if cv.waitKey(1) == ord('q'):
        break

# When everything done, release the capture
cap.release()
cv.destroyAllWindows()
